Array<T> class abstract interface

Implemented types
Available extensions

Constructors

Array(int length, {int offset = oneIndexedArrayOffset})
factory
Array.fromData(List<T> list, {int offset})
factory
Array.fromList(List<T> list, {int offset = oneIndexedArrayOffset})
factory
Array.fromSlice(List<T> elements, {int offset = oneIndexedArrayOffset})
factory

Properties

first ↔ T
The first element.
getter/setter pairinherited
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
hashCode → int
The hash code for this object.
no setterinherited
indexed → Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<T>
A new Iterator that allows iterating the elements of this Iterable.
no setterinherited
last ↔ T
The last element.
getter/setter pairinherited
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length ↔ int
The number of objects in this list.
getter/setter pairinherited
nonNulls → Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
offset → int
no setter
reversed → Iterable<T>
An Iterable of the objects in this list in reverse order.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → T
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
toJS → JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or cloning the List.
no setter
toJSIterable → JSIterable<T>

Available on Iterable<T>, provided by the IterableToJSIterable extension

A JSIterable wrapper that proxies to the Dart iterable API.
no setter
toJSProxyOrRef → JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or proxying the List.
no setter
value ↔ T
getter/setter pairinherited
wait → Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

a(int w, [int? len, String separator = '']) → String

Available on Iterable<String>, provided by the StringIterableFormatSpecifiersExtension extension

a1([int? len, String separator = '']) → String

Available on Iterable<String>, provided by the StringIterableFormatSpecifiersExtension extension

add(T value) → void
Adds value to the end of this list, extending the length by one.
inherited
addAll(Iterable<T> iterable) → void
Appends all objects of iterable to the end of this list.
inherited
any(bool test(T element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
asMap() → Map<int, T>
An unmodifiable Map view of this list.
inherited
asMatrix([int ld]) → Matrix<T>
asNameMap() → Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
assign(Array<T> array) → void
box(int index) → Box<T>
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
call(int index, {int? offset}) → Array<T>
cast<R>() → Array<R>
Returns a view of this list as a list of R instances.
override
clear() → void
Removes all objects from this list; the length of the list becomes zero.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
copy() → Array<T>
d(int w, [int d = 0, int? len, String separator = '']) → String

Available on Iterable<double>, provided by the DoubleIterableFormatSpecifiersExtension extension

d12_3(int x) → String

Available on Array<double>, provided by the DoubleArrayFormatSpecifiersExtension extension

d12_4([int? len, String separator = '']) → String

Available on Iterable<double>, provided by the DoubleIterableFormatSpecifiersExtension extension

d3([int? len, String separator = '']) → String

Available on Iterable<double>, provided by the DoubleIterableFormatSpecifiersExtension extension

d36_8([int? len, String separator = '']) → String

Available on Iterable<double>, provided by the DoubleIterableFormatSpecifiersExtension extension

d5([int? len, String separator = '']) → String

Available on Iterable<double>, provided by the DoubleIterableFormatSpecifiersExtension extension

elementAt(int index) → T
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
every(bool test(T element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(T element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
f6_1(int x) → String

Available on Array<double>, provided by the DoubleArrayFormatSpecifiersExtension extension

fillRange(int start, int end, [T? fillValue]) → void
Overwrites a range of elements with fillValue.
inherited
firstWhere(bool test(T element), {T orElse()?}) → T
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, T element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<T> other) → Iterable<T>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(T value)) → void
Invokes action on each element of this iterable in iteration order.
inherited
getRange(int start, int end) → Iterable<T>
Creates an Iterable that iterates over a range of elements.
inherited
having({int? length, int? offset}) → Array<T>
i(int w, [int? len, String separator = '']) → String

Available on Iterable<int>, provided by the IntIterableFormatSpecifiersExtension extension

i(int w, int len, [String separator = '']) → String

Available on Array<int>, provided by the IntArrayFormatSpecifiersExtension extension

i3([int? len, String separator = '']) → String

Available on Iterable<int>, provided by the IntIterableFormatSpecifiersExtension extension

i36([int? len, String separator = '']) → String

Available on Iterable<int>, provided by the IntIterableFormatSpecifiersExtension extension

i4(int len, [String separator = '']) → String

Available on Array<int>, provided by the IntArrayFormatSpecifiersExtension extension

i5(int len, [String separator = '']) → String

Available on Array<int>, provided by the IntArrayFormatSpecifiersExtension extension

i5([int? len, String separator = '']) → String

Available on Iterable<int>, provided by the IntIterableFormatSpecifiersExtension extension

i6(int len, [String separator = '']) → String

Available on Array<int>, provided by the IntArrayFormatSpecifiersExtension extension

i8(int len, [String separator = '']) → String

Available on Array<int>, provided by the IntArrayFormatSpecifiersExtension extension

indexOf(T element, [int start = 0]) → int
The first index of element in this list.
inherited
indexWhere(bool test(T element), [int start = 0]) → int
The first index in the list that satisfies the provided test.
inherited
insert(int index, T element) → void
Inserts element at position index in this list.
inherited
insertAll(int index, Iterable<T> iterable) → void
Inserts all objects of iterable at position index in this list.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastIndexOf(T element, [int? start]) → int
The last index of element in this list.
inherited
lastIndexWhere(bool test(T element), [int? start]) → int
The last index in the list that satisfies the provided test.
inherited
lastWhere(bool test(T element), {T orElse()?}) → T
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(T e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
maxloc(int start, int end, {int dim = 1}) → int

Available on Array<T>, provided by the ArrayExtension extension

maxval(int start, int end) → T

Available on Array<T>, provided by the ArrayExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(T combine(T value, T element)) → T
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
remove(Object? value) → bool
Removes the first occurrence of value from this list.
inherited
removeAt(int index) → T
Removes the object at position index from this list.
inherited
removeLast() → T
Removes and returns the last object in this list.
inherited
removeRange(int start, int end) → void
Removes a range of elements from the list.
inherited
removeWhere(bool test(T element)) → void
Removes all objects from this list that satisfy test.
inherited
replaceRange(int start, int end, Iterable<T> replacements) → void
Replaces a range of elements with the elements of replacements.
inherited
retainWhere(bool test(T element)) → void
Removes all objects from this list that fail to satisfy test.
inherited
setAll(int index, Iterable<T> iterable) → void
Overwrites elements with the objects of iterable.
inherited
setRange(int start, int end, Iterable<T> iterable, [int skipCount = 0]) → void
Writes some elements of iterable into a range of this list.
inherited
shuffle([Random? random]) → void
Shuffles the elements of this list randomly.
inherited
singleWhere(bool test(T element), {T orElse()?}) → T
The single element that satisfies test.
inherited
skip(int count) → Iterable<T>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(T element)) → Iterable<T>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
slice(int index, {int? offset}) → Array<T>
sort([int compare(T a, T b)?]) → void
Sorts this list according to the order specified by the compare function.
inherited
sublist(int start, [int? end]) → List<T>
Returns a new list containing the elements between start and end.
inherited
take(int count) → Iterable<T>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(T element)) → Iterable<T>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toComplexList() → List<Complex>

Available on List<ComplexTuple>, provided by the ComplexListTupleExtension extension

toData() → List<T>
toList({bool growable = true}) → List<T>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<T>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
A string representation of this object.
inherited
where(bool test(T element)) → Iterable<T>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator +(List<T> other) → List<T>
Returns the concatenation of this list and other.
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → T
The object at the given index in the list.
inherited
operator []=(int index, T value) → void
Sets the value at the given index in the list to value.
inherited