Complex class abstract

Available extensions

Constructors

Complex(double real, [double imaginary])
const
factory
Complex.fromFloat64x2(Float64x2 float)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
imaginary → double
no setter
isNaN → bool
no setter
real → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

abs() → double
cabs1() → double

Available on Complex, provided by the FunctionExtensions extension

cabs2() → double

Available on Complex, provided by the FunctionExtensions extension

cabsSq() → double

Available on Complex, provided by the FunctionExtensions extension

conjugate() → Complex
cos() → Complex
exp() → Complex
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pow(num x) → Complex
sin() → Complex
sqrt() → Complex
toDouble() → double
toFloat64x2() → Float64x2

Available on Complex, provided by the ComplexFloat64x2Extension extension

toInt() → int
toString() → String
A string representation of this object.
override

Operators

operator *(Complex other) → Complex
operator +(Complex other) → Complex
operator -(Complex other) → Complex
operator /(Complex other) → Complex
operator <(Complex other) → bool
operator <=(Complex other) → bool
operator ==(Object other) → bool
The equality operator.
override
operator >(Complex other) → bool
operator >=(Complex other) → bool
operator unary-() → Complex

Constants

nan → const Complex
one → const Complex
zero → const Complex