Matrix3dItemAccessor2<T> class

Constructors

Matrix3dItemAccessor2(Matrix3d<T> _m, int _i, int _j)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int k) → T
operator []=(int k, T value) → void