Nin class

Constructors

Nin(Stream<List<int>> stream)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read2<T1, T2>() → Future<(T1, T2)>
readArray<T>(Array<T> a, int n) → Future<void>
readBool() → Future<bool>
readBoxes<T>(Box<T> b1, [Box<T>? b2, Box<T>? b3, Box<T>? b4, Box<T>? b5, Box<T>? b6, Box<T>? b7, Box<T>? b8]) → Future<void>
readData<T>(int n) → Future<List<T>>
readDouble() → Future<double>
readDouble2() → Future<(double, double)>
readDouble4() → Future<(double, double, double, double)>
readInt() → Future<int>
readInt2() → Future<(int, int)>
readInt3() → Future<(int, int, int)>
readInt4() → Future<(int, int, int, int)>
readLine() → Future<String>
readList() → Future<List<String>>
readMatrix<T>(Matrix<T> a, int m, int n) → Future<void>
readString() → Future<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited